;; Generated package description from window-tool-bar.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "window-tool-bar" "0.3.0.20250226.15703" "Add tool bars inside windows" '((emacs "27.1") (compat "29.1")) :commit "ea12982ebedd89529c0265dec117db88e7e9ca40" :authors '(("Jared Finder" . "jared@finder.org")) :maintainer '("Jared Finder" . "jared@finder.org") :keywords '("mouse") :url "http://github.com/chaosemer/window-tool-bar")
